@@ -11,7 +11,6 @@
 
 #include <QIcon>
 #include <QDebug>
-#include <QtMac>
 
 #import <AppKit/AppKit.h>
 #import <Foundation/Foundation.h>
@@ -114,11 +113,6 @@ MacOSNotificationCenterPrivate::~MacOSNotificationCenterPrivate()
     [[NSUserNotificationCenter defaultUserNotificationCenter] setDelegate: nil];
     [m_delegate release];
 
-    // Try to finish all KNotification
-    for (auto it = m_notifications.constBegin(); it != m_notifications.constEnd(); it++) {
-        it.value()->deref();
-    }
-
     // Try to finish all NSNotification
     NSArray<NSUserNotification *> *deliveredNotifications = [NSUserNotificationCenter defaultUserNotificationCenter].deliveredNotifications;
     for (NSUserNotification *deliveredNotification in deliveredNotifications) {
@@ -148,9 +142,9 @@ NotifyByMacOSNotificationCenter::NotifyByMacOSNotificationCenter(QObject* parent
 
 NotifyByMacOSNotificationCenter::~NotifyByMacOSNotificationCenter() {}
 
-void NotifyByMacOSNotificationCenter::notify(KNotification *notification, KNotifyConfig *config)
+void NotifyByMacOSNotificationCenter::notify(KNotification *notification, const KNotifyConfig &notifyConfig)
 {
-    Q_UNUSED(config);
+    Q_UNUSED(notifyConfig);
 
     int internalId = MacOSNotificationCenterPrivate::instance()->m_internalCounter++;
     NSUserNotification *osxNotification = [[[NSUserNotification alloc] init] autorelease];
@@ -227,8 +221,10 @@ void NotifyByMacOSNotificationCenter::close(KNotification *notification)
     finish(notification);
 }
 
-void NotifyByMacOSNotificationCenter::update(KNotification *notification, KNotifyConfig *config)
+void NotifyByMacOSNotificationCenter::update(KNotification *notification, const KNotifyConfig &notifyConfig)
 {
     close(notification);
-    notify(notification, config);
+    notify(notification, notifyConfig);
 }
+
+#include "moc_notifybymacosnotificationcenter.cpp"
